@@ -1,6 +1,8 @@
 import http.client
 import json
+
 from payout.create_payout_account import CreatePayoutAccount
+from payout.update_payout_account import UpdatePayoutAccount
 
 
 class Payout:
@@ -32,7 +34,9 @@ class Payout:
         return create_payout_account.Process(request)
 
     def UpdatePayoutAccount(self, request):
-        pass
+        update_payout_account = UpdatePayoutAccount(
+            self.app, self.key, self.dataEndpoints)
+        return update_payout_account.Process(request)
 
     def AddPaymentRate(self, request):
         pass
